﻿Imports System.Collections.ObjectModel
Imports MindFusion.Charting
Imports MindFusion.Charting.WinForms
Imports MindFusion.Charting.Components

Imports Brush = MindFusion.Drawing.Brush
Imports SolidBrush = MindFusion.Drawing.SolidBrush


Public Class MainForm
	Private Sub Form1_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
		' create dashboard
		dashboard.Dock = DockStyle.Fill
		dashboard.Anchor = AnchorStyles.Bottom Or AnchorStyles.Left Or AnchorStyles.Right Or AnchorStyles.Top
		dashboard.Padding = New Padding(10)
		dashboard.BackColor = Color.White
		dashboard.Theme.PlotBackground = New MindFusion.Drawing.LinearGradientBrush(Color.White, Color.FromArgb(224, 233, 233), 90)
		dashboard.Theme.CommonSeriesFills = GetFills(255)
		dashboard.Theme.CommonSeriesStrokes = GetFills(255)

		Dim mainGrid = New GridPanel()
		mainGrid.HorizontalAlignment = LayoutAlignment.Stretch
		mainGrid.VerticalAlignment = LayoutAlignment.Stretch
		mainGrid.Columns.Add(New GridColumn())
		dashboard.RootPanel.Children.Add(mainGrid)

		' create plots grid
		Dim plotGrid = New GridPanel()
		plotGrid.GridColumn = 1
		plotGrid.GridRow = 0
		plotGrid.Columns.Add(New GridColumn())
		plotGrid.Columns.Add(New GridColumn())
		mainGrid.Children.Add(plotGrid)

		' add plot1
		Dim plot1 = New Plot2D()
		plot1.GridColumn = 0
		plot1.VerticalScroll = False
		plot1.AllowPan = False
		plot1.HighlightStroke = New SolidBrush(Color.Tomato)
		plot1.HighlightStrokeThickness = 1.0F
		Dim lineRenderer = New LineRenderer(GetSeriesCollection())
		plot1.SeriesRenderers.Add(lineRenderer)
		plotGrid.Children.Add(plot1)

		' add plot2
		Dim plot2 = New Plot3D()
		plot2.GridColumn = 1
		plot2.AllowPan = False
		plot2.VerticalScroll = False
		plot2.HighlightStroke = New SolidBrush(Color.Tomato)
		plot2.HighlightStrokeThickness = 1.0F
		Dim barRenderer = New BarOverlayRenderer3D(GetSeriesCollection())
		barRenderer.SeriesStyle = New PerSeriesStyle With {.Fills = GetFills(150)}
		barRenderer.BarSpacingRatio = 1
		plot2.SeriesRenderers.Add(barRenderer)
		plotGrid.Children.Add(plot2)

		' add plot3
		Dim plot3 = New Plot2D()
		plot3.AllowPan = False
		plot3.GridColumn = 2
		plot3.VerticalScroll = False
		plot3.HighlightStroke = New SolidBrush(Color.Tomato)
		plot1.HighlightStrokeThickness = 1.0F
		plot3.SeriesRenderers.Add(New StepRenderer(GetSeriesCollection()))
		plotGrid.Children.Add(plot3)

		' add axis
		Dim xa = New Axis() With {.Title = "Months"}
		Dim ya = New Axis() With {.MinValue = 0, .MaxValue = 100000, .Interval = 5000, .Title = "Revenues"}

		ya.NumberFormat = "C"
		Dim yAxis = New YAxisRenderer(ya, xa)
		yAxis.GridColumn = 0
		yAxis.PlotLeftSide = True
		yAxis.LabelsSource = plot1
		yAxis.AxisStroke = New SolidBrush(Color.SteelBlue)
		yAxis.AxisStrokeThickness = 1
		yAxis.TitleBrush = New SolidBrush(Color.SteelBlue)
		yAxis.TitleFontSize = 10.0F
		yAxis.TitleFontStyle = FontStyle.Bold
		yAxis.LabelBrush = New SolidBrush(Color.SteelBlue)
		mainGrid.Children.Add(yAxis)

		' attach plots to axis
		plot1.XAxis = xa
		plot2.XAxis = xa
		plot3.XAxis = xa
		plot1.YAxis = ya
		plot2.YAxis = ya
		plot3.YAxis = ya

	End Sub

	Private Function GetSeriesCollection() As ObservableCollection(Of Series)
		Dim collection As New ObservableCollection(Of Series)()
		For i As Integer = 0 To 2
			If i = 0 Then
				collection.Add(New Series2D(New Double() {0, 1, 2, 3}, New Double() {25000, 50000, 40000, 55000}, _
					New String() {"January", "February", "March", "April"}) With {.Title = "Series 1"})
			End If
			If i = 1 Then
				collection.Add(New Series2D(New Double() {0, 1, 2, 3}, New Double() {30000, 70000, 65000, 15000}, _
					   New String() {"May", "June", "July", "August"}) With {.Title = "Series 2"})
			End If
			If i = 2 Then
				collection.Add(New Series2D(New Double() {0, 1, 2, 3}, New Double() {20000, 45000, 35000, 65000}, _
		New String() {"September", "October", "November", "December"}) With {.Title = "Series 3"})
			End If
		Next
		Return collection
	End Function

	Private Function GetFills(alpha As Integer) As List(Of MindFusion.Drawing.Brush)
		Dim fills As New List(Of MindFusion.Drawing.Brush)()

		fills.Add(New SolidBrush(Color.FromArgb(alpha, Color.FromArgb(102, 154, 204))))
		fills.Add(New SolidBrush(Color.FromArgb(alpha, Color.FromArgb(0, 0, 99))))
		fills.Add(New SolidBrush(Color.FromArgb(alpha, Color.FromArgb(206, 0, 0))))

		Return fills
	End Function

End Class
